# uratools

This Python module provides tools to simplify the use of URANIE with Python


## URANIE

 - Website: https://uranie.cea.fr/
 - Python documentation: https://uranie.cea.fr/documentation/userManual_Py/index 
 - Installation: https://gitlab.com/uranie-cea/publication/-/wikis/home 

## Installation

```bash
pip install uratools
```

## How to use it

Before using the package, ensure that URANIE is installed and properly sourced.

The python command to use the package is the following

```python
from uratools import converter
```

You can get the doc by following commands 

```bash
pydoc uratools
```

```python
help(uratools.converter)
```

```python
print(uratools.converter.ds2np.__doc__)
```



## Example

```python
import numpy as np
import ROOT
from ROOT.URANIE import DataServer, Sampler
from uratools import converter

## == np.array to DataServer
mA = np.random.randn(10,2)
tds = converter.np2ds(mA, "x1:x2") ## a DataServer.TDataServer is created from np.array

## == DataServer to np.array 
tds = DataServer.TDataServer()
tds.addAttribute(DataServer.TUniformDistribution("x1",0.0, 5.0))
tds.addAttribute(DataServer.TNormalDistribution("x2",-2.0, 0.5))
sam = Sampler.TSampling(tds,"lhs",20)
sam.generateSample()

npA = converter.ds2np(tds) ## a np.array is created from a DataServer.TDataServer
```

## Authors

 - Rudy Chocat <mailto:rudy.chocat@cea.fr>
 - Gabriel Sarazin  <mailto:gabriel.sarazin@cea.fr>
 - Julien Nespoulous  <mailto:julien.nespoulous@cea.fr>
