import numpy as np
import ROOT
from ROOT.URANIE import DataServer

## to convert a TDataServer into a NumPy array
def ds2np(tds):
    ''' Create a *numpy.array* from a *DataServer.TDataServer*

    Parameters:
    * tds (DataServer.TDataServer): Dataserver with data

    Returns:
    * numpy.array: numpy array of values
    '''
    name = tds.getStringListOfAttributes()
    mat = np.empty( shape=( tds.getNPatterns() , tds.getNAttributes() ), dtype=float)
    tds.getTuple().extractData(mat , mat.size, name)
    return mat

## to convert a NumPy array into a TDataServer
def np2ds(mat, attrib_names, name="", title=""):
    ''' Create a *DataServer.TDataServer* from  *numpy.array*.

    Parameters:
    * np.array x:  *numpy.array* with data
    * string VarList: string with the name of attributes (*e.g.* "x1:x2", default ``""``)
    * string nameTds: name of *DataServer.TDataServer* (par défaut ``""``)
    * string titleTds: title *DataServer.TDataServer* (par défaut ``""``)

    Returns:
    * DataServer.TDataServer: nDataServer.TDataServer
    '''
    tds = DataServer.TDataServer(name, title)
    if len(mat.shape) < 2:
        mat = np.reshape(mat, (1, mat.size))
    ls_attrib_names = attrib_names.split(":")
    for name in ls_attrib_names:
        data  = np.ascontiguousarray(mat.transpose()[ ls_attrib_names.index(name) ])
        tds.addAttributeUsingData(name, data, data.size)
        pass
    return tds

